<?php

/*
* Plugin Name: PH UPS Return Label Type addon
* Plugin URI:https://www.pluginhive.com/plugins/
* Description: This addon is not an independant plugin and requires PluginHive WooCommerce UPS Shipping plugin with Print Label plugin to work. It will allow you to choose from the Forward or Return UPS shipping label while processing the WooCommerce orders.
* Author: PluginHive
* Author URI: https://pluginhive.com/
* Version: 1.0.0
* Text Domain: ph_ups_return_label_type_addon
* Copyright: 2021 PluginHive.
* WC requires at least: 3.0.0
* WC tested up to: 5.8.0
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

function ph_return_label_type_addon_required_plugin_check(){

	$ph_addon_required_plugin 	= false;

	$active_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) );

	// Multisite case
	if ( is_multisite() ) {
		$active_plugins = array_merge( $active_plugins, array_keys( get_site_option( 'active_sitewide_plugins', array() ) ) );
	}

	if ( in_array( 'woocommerce/woocommerce.php', $active_plugins ) && in_array( 'ups-woocommerce-shipping/ups-woocommerce-shipping.php', $active_plugins ) ) {

		$ph_addon_required_plugin = true;
	}

	return $ph_addon_required_plugin;
}

// Auto Deactivate
add_action( 'admin_init', 'ph_ups_return_label_type_addon' );

if ( ! function_exists( 'ph_ups_return_label_type_addon' ) ) {
	function ph_ups_return_label_type_addon() {

		$ph_required_plugin	= ph_return_label_type_addon_required_plugin_check();

		if ( !$ph_required_plugin ) {

			deactivate_plugins( plugin_basename( __FILE__ ) );
			wp_safe_redirect( admin_url('plugins.php') );
		}
	}
}

function ph_ups_return_label_type_addon_activation_check(){

	$ph_required_plugin 	= ph_return_label_type_addon_required_plugin_check();

	if(  !$ph_required_plugin ) {

		deactivate_plugins( basename( __FILE__ ) );
		wp_die( __("Oops! You tried installing this without activating WooCommerce/WooCommerce UPS Shipping Plugin with Print Label.", 'ph_ups_return_label_type_addon' ), "", array('back_link' => 1 ));
	}
}

register_activation_hook( __FILE__, 'ph_ups_return_label_type_addon_activation_check' );

if( !class_exists('Ph_UPS_Return_Label_Type_Addon') ) {

	class Ph_UPS_Return_Label_Type_Addon {

		public function __construct() {

			$this->id		= 'ph_ups_return_label_type_addon';

			add_action( 'admin_enqueue_scripts', array( $this, 'ph_pass_ups_modified_label_data'));

			require_once( 'includes/ph_ups_modified_return_label.php' );
		}

		public function ph_pass_ups_modified_label_data() {

			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'jquery-ui-dialog' );
			wp_enqueue_style( 'ph-common-style', plugins_url( '/resources/css/ph_common_style.css', __FILE__ ));
			wp_enqueue_script( 'ph-ups-return-label-bulk-action', plugins_url( '/resources/js/jquery-block.js', __FILE__ ), array( 'jquery' ) );
			wp_enqueue_script( 'ph-ups-return-label', plugins_url( '/resources/js/ph-modified-return-label.js', __FILE__ ), array( 'jquery' ) );
		}
	}

	new Ph_UPS_Return_Label_Type_Addon();
}

